@@ -1,7 +1,8 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Codepeek;
-$App::Nopaste::Service::Codepeek::VERSION = '1.003';
+# ABSTRACT: (DEPRECATED) Service for Codepeek - http://codepeek.com
+our $VERSION = '1.004';
 use base 'App::Nopaste::Service';
 
 sub uri { 'http://codepeek.com/paste' }
@@ -33,20 +34,38 @@ sub return {
 }
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-App::Nopaste::Service::Codepeek - http://codepeek.com
+App::Nopaste::Service::Codepeek - (DEPRECATED) Service for Codepeek - http://codepeek.com
 
 =head1 VERSION
 
-version 1.003
+version 1.004
+
+=head1 DEPRECATION NOTICE
+
+L<http://codepeek.com> is now offline, so this service no longer works.
 
 =head1 AUTHOR
 
 Justin Hunter, C<< <justin.d.hunter@gmail.com> >>
 
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
